Params class abstract

The abstract base class for all input parameter objects passed to a Usecase.

By enforcing a single, typed object as input, the Usecase signature remains stable, improving maintainability and clarity even if the required parameters change.

All concrete parameter classes must be immutable and define validation logic.

Implementers
Annotations
  • @immutable

Constructors

Params()
The abstract base class for all input parameter objects passed to a Usecase.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotValid bool
Returns the inverse of isValid. True if the parameters are not valid.
no setter
isValid bool
Checks if the parameters contained within this object are valid for Usecase execution (e.g., non-null, correct format, etc.).
no setter
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited